package com.visa.application.controller;

import com.visa.application.service.OrderProducerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import reactor.core.publisher.Mono;

@RestController
@RequestMapping("/api/orders")
public class OrderController {

    private static final Logger logger = LoggerFactory.getLogger(OrderController.class);

    @Autowired
    private OrderProducerService orderProducerService;

    @GetMapping("/publish")
    public Mono<ResponseEntity<String>> publishOrdersToKafka() {
        return orderProducerService.publishOrdersToKafka()
                .then(Mono.just(ResponseEntity.ok("Orders are being published to Kafka")))
                .onErrorResume(e -> {
                    logger.error("Error publishing orders to Kafka", e);
                    return Mono.just(ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR)
                            .body("Failed to publish orders to Kafka"));
                });
    }
}


