package com.visa.application.service;

import com.visa.application.entity.Order;
import com.visa.application.repository.OrderRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.annotation.EnableKafka;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

@Service
@EnableKafka
public class OrderConsumerService {

    @Autowired
    private OrderRepository orderRepository;

    // Kafka listener to consume messages from the 'order-topic' topic
    @KafkaListener(topics = "order-topic", groupId = "my-consumer-group", containerFactory = "kafkaListenerContainerFactory")
    public void consumeOrder(Order order) {
        System.out.println("Consumed Order: " + order);

        // Save the consumed order to MongoDB
        saveOrderToMongo(order).subscribe();
    }

    private Mono<Order> saveOrderToMongo(Order order) {
        return orderRepository.save(order)
                .doOnSuccess(savedOrder -> System.out.println("Saved to MongoDB: " + savedOrder))
                .doOnError(err -> System.err.println("Error saving to MongoDB: " + err.getMessage()));
    }
}

