package com.visa.application.service;

import com.visa.application.entity.Order;
import com.visa.application.repository.OrderRepository;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

@Service
public class OrderProducerService {

    private static final Logger logger = LoggerFactory.getLogger(OrderProducerService.class);

    @Autowired
    private OrderRepository orderRepository;

    @Autowired
    private KafkaTemplate<String, Object> kafkaTemplate;

    private static final String TOPIC = "order-topic";

    public Mono<Void> publishOrdersToKafka() {
        Flux<Order> ordersFlux = orderRepository.findAll();

        return ordersFlux
                .flatMap(this::sendOrderToKafka)
                .then()
                .doOnError(e -> logger.error("Error occurred while publishing orders to Kafka", e))
                .doOnSuccess(aVoid -> logger.info("All orders successfully published to Kafka"));
    }

    private Mono<Order> sendOrderToKafka(Order order) {
        return Mono.create(sink -> {
            kafkaTemplate.send(TOPIC, order.getId(), order)
                    .addCallback(
                            result -> {
                                logger.info("Order with ID {} successfully sent to Kafka", order.getId());
                                sink.success(order);
                            },
                            ex -> {
                                logger.error("Failed to send order with ID {} to Kafka", order.getId(), ex);
                                sink.error(ex);
                            }
                    );
        });
    }
}


